#[repr(i32)]pub enum OutputClassification {
Unspecified = 0,
Confidential = 1,
RunPrivate = 2,
Public = 3,
}Variants
Unspecified = 0
Confidential = 1
RunPrivate = 2
Public = 3
Public, provenance-bound output that may be routed only through a declared run binding. It is not a confidential value and may be recorded in reviewed public observations, but it must still match the action contract exactly.
Implementations
Sourceimpl OutputClassification
impl OutputClassification
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of OutputClassification.
Sourcepub fn from_i32(value: i32) -> Option<OutputClassification>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OutputClassification>
Converts an i32 to a OutputClassification, or None if value is not a valid variant.
Sourceimpl OutputClassification
impl OutputClassification
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.