ActionOutputDecl

Struct ActionOutputDecl 

pub struct ActionOutputDecl {
    pub binding_id: String,
    pub output_name: String,
    pub classification: i32,
    pub max_bytes: u32,
    pub value_type: i32,
    pub sink_binding: String,
    pub allow_overwrite: bool,
}

Fields

binding_id: Stringoutput_name: Stringclassification: i32max_bytes: u32value_type: i32sink_binding: Stringallow_overwrite: bool

Implementations

Source

impl ActionOutputDecl

pub fn classification(&self) -> OutputClassification

Returns the enum value of classification, or the default if the field is set to an invalid enum value.

pub fn set_classification(&mut self, value: OutputClassification)

Sets classification to the provided enum value.

pub fn value_type(&self) -> BindingValueType

Returns the enum value of value_type, or the default if the field is set to an invalid enum value.

pub fn set_value_type(&mut self, value: BindingValueType)

Sets value_type to the provided enum value.