pub struct PlanRequest {
pub context: Option<RequestContext>,
pub desired_json: Vec<u8>,
pub observations_json: Vec<u8>,
pub secrets: HashMap<String, Vec<u8>>,
pub resource_contexts: HashMap<String, ResourcePlanContext>,
pub enrollment_strategy: i32,
pub planning_mode: i32,
}Fields
context: Option<RequestContext>desired_json: Vec<u8>observations_json: Vec<u8>secrets: HashMap<String, Vec<u8>>resource_contexts: HashMap<String, ResourcePlanContext>enrollment_strategy: i32planning_mode: i32Implementations
Sourceimpl PlanRequest
impl PlanRequest
Sourcepub fn enrollment_strategy(&self) -> EnrollmentStrategy
pub fn enrollment_strategy(&self) -> EnrollmentStrategy
Returns the enum value of enrollment_strategy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_enrollment_strategy(&mut self, value: EnrollmentStrategy)
pub fn set_enrollment_strategy(&mut self, value: EnrollmentStrategy)
Sets enrollment_strategy to the provided enum value.
Sourcepub fn planning_mode(&self) -> PlanningMode
pub fn planning_mode(&self) -> PlanningMode
Returns the enum value of planning_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_planning_mode(&mut self, value: PlanningMode)
pub fn set_planning_mode(&mut self, value: PlanningMode)
Sets planning_mode to the provided enum value.