pub struct ProviderError {
pub category: i32,
pub safe_message: String,
pub retryable: bool,
pub ambiguous: bool,
}Fields
category: i32safe_message: Stringretryable: boolambiguous: boolImplementations
Sourceimpl ProviderError
impl ProviderError
Sourcepub fn category(&self) -> ErrorCategory
pub fn category(&self) -> ErrorCategory
Returns the enum value of category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_category(&mut self, value: ErrorCategory)
pub fn set_category(&mut self, value: ErrorCategory)
Sets category to the provided enum value.