pub struct ActionOutputDecl {
pub binding_id: String,
pub output_name: String,
pub classification: i32,
pub max_bytes: u32,
pub value_type: i32,
pub sink_binding: String,
pub allow_overwrite: bool,
}Fields
binding_id: Stringoutput_name: Stringclassification: i32max_bytes: u32value_type: i32sink_binding: Stringallow_overwrite: boolImplementations
Sourceimpl ActionOutputDecl
impl ActionOutputDecl
Sourcepub fn classification(&self) -> OutputClassification
pub fn classification(&self) -> OutputClassification
Returns the enum value of classification, or the default if the field is set to an invalid enum value.
Sourcepub fn set_classification(&mut self, value: OutputClassification)
pub fn set_classification(&mut self, value: OutputClassification)
Sets classification to the provided enum value.
Sourcepub fn value_type(&self) -> BindingValueType
pub fn value_type(&self) -> BindingValueType
Returns the enum value of value_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_value_type(&mut self, value: BindingValueType)
pub fn set_value_type(&mut self, value: BindingValueType)
Sets value_type to the provided enum value.